﻿using System.Collections.Generic;
using System.Web.Mvc;

using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;

namespace DocIOApplication.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index(string button1, string message)
        {
            if (button1 == null)
                return View();
            WordDocument document = new WordDocument(Server.MapPath(@"App_Data\Template.docx"));
            

            // Removes merge fileds from template document.
            RemoveMergeField(document,"test");

            //Rename the merge field.
            RenameMergeField(document, "sbw2", "sbw");
            
            document.Save("result.docx", FormatType.Docx, HttpContext.ApplicationInstance.Response,
                HttpContentDisposition.Attachment);
            return View();
        }
        /// <summary>
        /// Removes merge fileds from entire document.
        /// </summary>
        /// <param name="wordDocument">Word document</param>
        public void RemoveMergeField(WordDocument wordDocument,string fieldName)
        {
            //Find the field by its name using Find method.
            TextSelection selection = wordDocument.Find(fieldName, true, true);
            //Get owner paragraph.
            WParagraph ownerParagraph = selection.GetAsOneRange().OwnerParagraph;

            if(ownerParagraph != null )
            {
                for (int index = 0; index < ownerParagraph.ChildEntities.Count; index++)
                {
                    //Remove the Merge field from its owner paragraph child entities colection.
                    if (ownerParagraph.ChildEntities[index] is WMergeField
                        && (ownerParagraph.ChildEntities[index] as WMergeField).FieldName == fieldName)
                        ownerParagraph.ChildEntities.RemoveAt(index);
                }
            }
           
        }

        /// <summary>
        /// Rename the specified Merge field name.
        /// </summary>
        /// <param name="wordDocument">Word document</param>
        public void RenameMergeField(WordDocument wordDocument, string oldFieldName,string newFieldName)
        {
            //Find the field by its name using Find method.
            TextSelection selection = wordDocument.Find(oldFieldName, true, true);
            //Get owner paragraph.
            WParagraph ownerParagraph = selection.GetAsOneRange().OwnerParagraph;

            if (ownerParagraph != null)
            {
                for (int index = 0; index < ownerParagraph.ChildEntities.Count; index++)
                {
                    //Rename the Merge field.
                    if (ownerParagraph.ChildEntities[index] is WMergeField 
                        && (ownerParagraph.ChildEntities[index] as WMergeField).FieldName == oldFieldName)
                    {
                        (ownerParagraph.ChildEntities[index] as WMergeField).FieldName = newFieldName;
                    }
                }
            }

        }
    }
}